==> apache-ignite-3.0.0-src.zip: apache-ignite-3.0.0-src/modules/catalog/src/main/java/org/apache/ignite/internal/catalog/storage/serialization/CatalogObjectSerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.catalog.storage.serialization;

import java.io.IOException;
import org.apache.ignite.internal.util.io.IgniteDataInput;
import org.apache.ignite.internal.util.io.IgniteDataOutput;

/**
 * Catalog object serializer.
 */
public interface CatalogObjectSerializer<T> {
    /**
     * Reads catalog object from data input.
     *
     * @param input Data input.
     * @return Catalog entry.
     */
    T readFrom(IgniteDataInput input) throws IOException;

    /**
     * Writes catalog object to data output.
     *
     * @param value Catalog entry.
     * @param output Data output.
     */
    void writeTo(T value, IgniteDataOutput output) throws IOException;
}

==> apache-ignite-3.1.0-src.zip: apache-ignite-3.1.0-src/modules/catalog/src/main/java/org/apache/ignite/internal/catalog/storage/serialization/CatalogObjectSerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.catalog.storage.serialization;

import java.io.IOException;

/**
 * Catalog object serializer.
 *
 * <p>All implementations used in production (and not tied to a specific
 * version of another serializer) must be annotated with {@link CatalogSerializer}.
 *
 * @see CatalogSerializer
 */
public interface CatalogObjectSerializer<T> {
    /**
     * Reads catalog object from data input.
     *
     * @param input Data input.
     * @return Catalog entry.
     */
    T readFrom(CatalogObjectDataInput input) throws IOException;

    /**
     * Writes catalog object to data output.
     *
     * @param value Catalog entry.
     * @param output Data output.
     */
    void writeTo(T value, CatalogObjectDataOutput output) throws IOException;
}
